==> v2.1.0b1.zip: extract_otp_secret_keys/docs/README_TOC.md <==
Generate from file: README.md

## Table of contents

- [Table of contents](#table-of-contents)
- [Usage](#usage)
  - [Capture QR codes from camera (🆕 since version 2.0)](#capture-qr-codes-from-camera--since-version-20)
  - [With builtin QR decoder from image files (🆕 since version 2.0)](#with-builtin-qr-decoder-from-image-files--since-version-20)
  - [With external QR decoder app from text files](#with-external-qr-decoder-app-from-text-files)
- [Installation](#installation)
  - [Download binary executable (🆕 since v2.1)](#download-binary-executable--since-v21)
  - [Run as script (recommend for developers or advanced users)](#run-as-script-recommend-for-developers-or-advanced-users)
  - [Installation of shared system libraries](#installation-of-shared-system-libraries)
- [Program help: arguments and options](#program-help-arguments-and-options)
- [Examples](#examples)
  - [Printing otp secrets form text file](#printing-otp-secrets-form-text-file)
  - [Printing otp secrets from image file](#printing-otp-secrets-from-image-file)
  - [Writing otp secrets to csv file](#writing-otp-secrets-to-csv-file)
  - [Writing otp secrets to json file](#writing-otp-secrets-to-json-file)
  - [Printing otp secrets multiple files](#printing-otp-secrets-multiple-files)
  - [Printing otp secrets from stdin (text)](#printing-otp-secrets-from-stdin-text)
  - [Printing otp secrets from stdin (image)](#printing-otp-secrets-from-stdin-image)
  - [Printing otp secrets csv to stdout](#printing-otp-secrets-csv-to-stdout)
  - [Printing otp secrets csv to stdout without header line](#printing-otp-secrets-csv-to-stdout-without-header-line)
  - [Reading from stdin and printing to stdout](#reading-from-stdin-and-printing-to-stdout)
- [Features](#features)
- [KeePass](#keepass)
- [How to export otp secrets from Google Authenticator app](#how-to-export-otp-secrets-from-google-authenticator-app)
- [Glossary](#glossary)
- [Alternative installation methods](#alternative-installation-methods)
  - [pip using github](#pip-using-github)
  - [local pip](#local-pip)
  - [pipenv](#pipenv)
  - [Visual Studio Code Remote - Containers / VSCode devcontainer](#visual-studio-code-remote---containers--vscode-devcontainer)
  - [venv](#venv)
  - [devbox](#devbox)
  - [docker](#docker)
  - [More docker examples](#more-docker-examples)
- [Tests](#tests)
  - [PyTest](#pytest)
  - [unittest](#unittest)
  - [VSCode Setup](#vscode-setup)
- [Development](#development)
  - [Build](#build)
  - [Upgrade pip Packages](#upgrade-pip-packages)
  - [Build docker images](#build-docker-images)
  - [Create executables with pyinstaller](#create-executables-with-pyinstaller)
  - [Full local build (bash)](#full-local-build-bash)
- [Technical background](#technical-background)
- [References](#references)
- [Issues](#issues)
- [Problems and Troubleshooting](#problems-and-troubleshooting)
  - [Windows error message](#windows-error-message)
- [Related projects](#related-projects)

Table of contents generated.

==> v2.7.0.zip: extract_otp_secret_keys/docs/README_TOC.md <==
Generate from file: README.md

## Table of contents

- [Table of contents](#table-of-contents)
- [Download and run binary executable (🆕 since v2.1)](#download-and-run-binary-executable--since-v21)
  - [MacOS](#macos)
- [Usage](#usage)
  - [Capture QR codes from camera (🆕 since version 2.0)](#capture-qr-codes-from-camera--since-version-20)
  - [With builtin QR decoder from image files (🆕 since version 2.0)](#with-builtin-qr-decoder-from-image-files--since-version-20)
  - [With external QR decoder app from text files](#with-external-qr-decoder-app-from-text-files)
- [Installation of Python script (recommended for developers or advanced users)](#installation-of-python-script-recommended-for-developers-or-advanced-users)
  - [Installation of optional shared system libraries (recommended)](#installation-of-optional-shared-system-libraries-recommended)
- [Program help: arguments and options](#program-help-arguments-and-options)
- [Examples](#examples)
  - [Printing otp secrets form text file](#printing-otp-secrets-form-text-file)
  - [Printing otp secrets from image file](#printing-otp-secrets-from-image-file)
  - [Writing otp secrets to csv file](#writing-otp-secrets-to-csv-file)
  - [Writing otp secrets to json file](#writing-otp-secrets-to-json-file)
  - [Printing otp secrets multiple files](#printing-otp-secrets-multiple-files)
  - [Printing otp secrets from stdin (text)](#printing-otp-secrets-from-stdin-text)
  - [Printing otp secrets from stdin (image)](#printing-otp-secrets-from-stdin-image)
  - [Printing otp secrets csv to stdout](#printing-otp-secrets-csv-to-stdout)
  - [Printing otp secrets csv to stdout without header line](#printing-otp-secrets-csv-to-stdout-without-header-line)
  - [Reading from stdin and printing to stdout](#reading-from-stdin-and-printing-to-stdout)
- [Features](#features)
- [KeePass](#keepass)
- [How to export otp secrets from Google Authenticator app](#how-to-export-otp-secrets-from-google-authenticator-app)
- [Glossary](#glossary)
- [Alternative installation methods](#alternative-installation-methods)
  - [pip using github](#pip-using-github)
  - [local pip](#local-pip)
  - [pipenv](#pipenv)
  - [Visual Studio Code Remote - Containers / VSCode devcontainer](#visual-studio-code-remote---containers--vscode-devcontainer)
  - [venv](#venv)
  - [devbox](#devbox)
  - [docker](#docker)
  - [More docker examples](#more-docker-examples)
- [Tests](#tests)
  - [PyTest](#pytest)
  - [unittest](#unittest)
  - [VSCode Setup](#vscode-setup)
- [Development](#development)
  - [Build](#build)
  - [Upgrade pip Packages](#upgrade-pip-packages)
  - [Build docker images](#build-docker-images)
  - [Create executables with pyinstaller](#create-executables-with-pyinstaller)
  - [Full local build (bash)](#full-local-build-bash)
- [Technical background](#technical-background)
- [References](#references)
- [Issues](#issues)
- [Problems and Troubleshooting](#problems-and-troubleshooting)
  - [Windows error message](#windows-error-message)
- [Related projects](#related-projects)

Table of contents generated.
